"""
The FRANKENSTEIN is an architecture for language models that combines various submodels of different architectures
so that they can work together in order to deliver responses that are more accurate and better suited to the user's needs. Both local models and external models via API can be combined,
or even a combination of the two. These capabilities allow FRANKENSTEIN to infer both models with the proprietary architectures of Sapiens Technology®️,
as well as models with third-party architectures if there is such a need. The submodels are grouped into a classes structure capable of selecting one or more of them depending on the needs of the prompt.
When compiling the FRANKENSTEIN structure, a single model will be created through the result of the weights of all the local submodels contained in the architecture,
enabling packaging and distribution with a single file. Unlike what happens in a conventional MoE (Mixture of Experts),
FRANKENSTEIN does not need to load all submodels at once into memory and does not depend on all submodels belonging to the same architecture,
making it lighter and more flexible than a MoE and allowing it to run on more modest hardware.

Any alteration, copying, sharing, posting, or public comment about the technologies presented here without the prior authorization of Sapiens Technology®️ is strictly prohibited,
and failure to comply with these rules will result in legal proceedings initiated by our team of lawyers.
"""
# --------------------------> A SAPIENS TECHNOLOGY®️ PRODUCTION) <--------------------------
from .FRANKENSTEIN_MODEL import *
"""
The FRANKENSTEIN is an architecture for language models that combines various submodels of different architectures
so that they can work together in order to deliver responses that are more accurate and better suited to the user's needs. Both local models and external models via API can be combined,
or even a combination of the two. These capabilities allow FRANKENSTEIN to infer both models with the proprietary architectures of Sapiens Technology®️,
as well as models with third-party architectures if there is such a need. The submodels are grouped into a classes structure capable of selecting one or more of them depending on the needs of the prompt.
When compiling the FRANKENSTEIN structure, a single model will be created through the result of the weights of all the local submodels contained in the architecture,
enabling packaging and distribution with a single file. Unlike what happens in a conventional MoE (Mixture of Experts),
FRANKENSTEIN does not need to load all submodels at once into memory and does not depend on all submodels belonging to the same architecture,
making it lighter and more flexible than a MoE and allowing it to run on more modest hardware.

Any alteration, copying, sharing, posting, or public comment about the technologies presented here without the prior authorization of Sapiens Technology®️ is strictly prohibited,
and failure to comply with these rules will result in legal proceedings initiated by our team of lawyers.
"""
# --------------------------> A SAPIENS TECHNOLOGY®️ PRODUCTION) <--------------------------



"""
This is the main module of the “Frankenstein” architecture, with features for combining multiple submodels from different architectures that work in a coordinated way to provide responses with a high degree of accuracy.
The current module also includes pre-programmed functions for creating and loading files with the skeleton of the “Frankenstein” (frankenstein.json),
a function for the final assembly of the architecture based on the submodels configured in the “Frankenstein” file,
a function for packaging the submodels into a single closed model, and a function for inference of the generated “Frankenstein” model with the combination of all submodels.

Any alteration, customization, copying, or sharing of this module without prior authorization from Sapiens Technology®️ is strictly prohibited,
as are technical posts, public comments, or any disclosure of the technical information contained herein.
Failure to comply with these rules will result in legal proceedings initiated by our team of lawyers.
"""
# --------------------------> A SAPIENS TECHNOLOGY®️ PRODUCTION) <--------------------------
from setuptools import setup, find_packages
package_name = 'FRANKENSTEIN_MODEL'
version = '5.1.7.7'
setup(
    name=package_name,
    version=version,
    author='SAPIENS TECHNOLOGY',
    packages=find_packages(),
    install_requires=[
        'TTS==0.22.0',
        'torch==2.4.1',
        'torchvision==0.19.1',
        'torchaudio==2.4.1',
        'transformers==4.45.2',
        'megatron-core==0.10.0',
        'paddleocr==2.7.3',
        'paddlepaddle==2.6.2',
        'moviepy==1.0.3',
        'sapiens-frankenstein',
        'sapiens-transformers',
        'utilities-nlp',
        'sapiens-loader',
        'SUBMODELS'
    ],
    url='https://github.com/sapiens-technology/FRANKENSTEIN',
    license='Proprietary Software'
)
"""
This is the main module of the “Frankenstein” architecture, with features for combining multiple submodels from different architectures that work in a coordinated way to provide responses with a high degree of accuracy.
The current module also includes pre-programmed functions for creating and loading files with the skeleton of the “Frankenstein” (frankenstein.json),
a function for the final assembly of the architecture based on the submodels configured in the “Frankenstein” file,
a function for packaging the submodels into a single closed model, and a function for inference of the generated “Frankenstein” model with the combination of all submodels.

Any alteration, customization, copying, or sharing of this module without prior authorization from Sapiens Technology®️ is strictly prohibited,
as are technical posts, public comments, or any disclosure of the technical information contained herein.
Failure to comply with these rules will result in legal proceedings initiated by our team of lawyers.
"""
# --------------------------> A SAPIENS TECHNOLOGY®️ PRODUCTION) <--------------------------
